@@ -1,7 +1,7 @@
 package Complete::File;
 
-our $DATE = '2015-11-29'; # DATE
-our $VERSION = '0.39'; # VERSION
+our $DATE = '2016-05-09'; # DATE
+our $VERSION = '0.40'; # VERSION
 
 use 5.010001;
 use strict;
@@ -89,6 +89,7 @@ _
 };
 sub complete_file {
     require Complete::Path;
+    require Encode;
     require File::Glob;
 
     my %args   = @_;
@@ -106,7 +107,7 @@ sub complete_file {
         $result_prefix = "$1/";
         my @dir = File::Glob::glob($1); # glob will expand ~foo to /home/foo
         return [] unless @dir;
-        $starting_path = $dir[0];
+        $starting_path = Encode::decode('UTF-8', $dir[0]);
     } elsif ($allow_dot && $word =~ s!\A((?:\.\.?/+)+|/+)!!) {
         # just an optimization to skip sequences of '../'
         $starting_path = $1;
@@ -127,7 +128,7 @@ sub complete_file {
             # skip . and .. if leaf is empty, like in bash
             next if ($_ eq '.' || $_ eq '..') && $intdir eq '';
             next if $isint && !(-d "$path/$_");
-            push @res, $_;
+            push @res, Encode::decode('UTF-8', $_);
         }
         \@res;
     };
@@ -218,7 +219,7 @@ Complete::File - Completion routines related to files
 
 =head1 VERSION
 
-This document describes version 0.39 of Complete::File (from Perl distribution Complete-File), released on 2015-11-29.
+This document describes version 0.40 of Complete::File (from Perl distribution Complete-File), released on 2016-05-09.
 
 =head1 DESCRIPTION
 
@@ -318,12 +319,6 @@ Word to complete.
 
 Return value:  (array)
 
-=head1 SEE ALSO
-
-L<Complete>
-
-Other C<Complete::*> modules.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Complete-File>.
@@ -340,13 +335,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Complete>
+
+Other C<Complete::*> modules.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
